@@ -1,7 +1,7 @@
 """Constants package for PyVSS."""
 PACKAGE_NAME = "pyvss"
 
-__version__ = '0.17.0'
+__version__ = '0.17.1'
 
 API_ENDPOINT_BASE = 'https://cloud-api.eis.utoronto.ca'
 VSKEY_STOR_ENDPOINT = 'https://vskey-stor.eis.utoronto.ca'
@@ -167,3 +167,8 @@ VALID_VM_EXTRA_CFG = [
         "option": "guestinfo.",
     },
 ]
+
+VALID_VM_FIRMWARE_TYPE = [
+    {"description": "BIOS firmware", "type": "bios"},
+    {"description": "Extensible Firmware Interface", "type": "efi"},
+]
